@@ -9,8 +9,8 @@ from synalinks.src.backend import is_similarity_search
 from synalinks.src.backend import is_triplet_search
 from synalinks.src.knowledge_bases.database_adapters import DatabaseAdapter
 from synalinks.src.knowledge_bases.database_adapters.neo4j_adapter import Neo4JAdapter
-from synalinks.src.utils.naming import to_snake_case
 from synalinks.src.utils.async_utils import run_maybe_nested
+from synalinks.src.utils.naming import to_snake_case
 
 
 class MemGraphAdapter(Neo4JAdapter):
@@ -38,31 +38,37 @@ class MemGraphAdapter(Neo4JAdapter):
         )
 
     def wipe_database(self):
-        run_maybe_nested(
-            self.query("MATCH (n) DETACH DELETE n;")
-        )
+        run_maybe_nested(self.query("MATCH (n) DETACH DELETE n;"))
+        result = run_maybe_nested(self.query("SHOW VECTOR INDEXES"))
+        for indexes in result:
+            index_name = indexes["index_name"]
+            query = f"DROP VECTOR INDEX {index_name};"
+            run_maybe_nested(self.query(query))
 
     def create_vector_index(self):
         metric_mapping = {"cosine": "cos", "euclidean": "l2sq"}
         metric = metric_mapping[self.metric]
 
         for entity_model in self.entity_models:
-            node_label = self.sanitize_label(entity_model.get_schema().get("title"))
-            index_name = to_snake_case(node_label)
-            query = "\n".join(
-                [
-                    f"CREATE VECTOR INDEX {index_name} ",
-                    f"ON :{node_label}(embedding)",
-                    "WITH CONFIG {",
-                    f'  "dimension": {self.embedding_dim}, ',
-                    f'  "metric": "{metric}", ',
-                    '  "capacity": 1000',
-                    "};",
-                ]
-            )
-            run_maybe_nested(
-                self.query(query),
-            )
+            try:
+                node_label = self.sanitize_label(entity_model.get_schema().get("title"))
+                index_name = to_snake_case(node_label)
+                query = "\n".join(
+                    [
+                        f"CREATE VECTOR INDEX {index_name} ",
+                        f"ON :{node_label}(embedding)",
+                        "WITH CONFIG {",
+                        f'  "dimension": {self.embedding_dim}, ',
+                        f'  "metric": "{metric}", ',
+                        '  "capacity": 1000',
+                        "};",
+                    ]
+                )
+                run_maybe_nested(
+                    self.query(query),
+                )
+            except Exception:
+                pass
 
     async def update(
         self,
@@ -192,7 +198,7 @@ class MemGraphAdapter(Neo4JAdapter):
                 " $vector) YIELD node AS node, similarity AS score",
                 "WITH node, score",
                 "WHERE score >= $threshold",
-                "RETURN {name: node.name, label: node.label} AS node, score",
+                "RETURN node AS node, score",
                 "LIMIT $numberOfNearestNeighbours",
             ]
         )
@@ -228,7 +234,6 @@ class MemGraphAdapter(Neo4JAdapter):
         params = {
             "numberOfNearestNeighbours": k,
             "threshold": threshold,
-            "k": k,
         }
         query_lines = []
 
@@ -342,6 +347,6 @@ class MemGraphAdapter(Neo4JAdapter):
                 "sqrt(subj_score * obj_score) AS score"
             )
         )
-        query_lines.append("LIMIT $k")
+        query_lines.append("LIMIT $numberOfNearestNeighbours")
         query = "\n".join(query_lines)
         return await self.query(query, params)
