@@ -13,8 +13,8 @@ from synalinks.src.backend import is_similarity_search
 from synalinks.src.backend import is_triplet_search
 from synalinks.src.backend.common.json_utils import out_mask_json
 from synalinks.src.knowledge_bases.database_adapters import DatabaseAdapter
-from synalinks.src.utils.naming import to_snake_case
 from synalinks.src.utils.async_utils import run_maybe_nested
+from synalinks.src.utils.naming import to_snake_case
 
 
 class Neo4JAdapter(DatabaseAdapter):
@@ -49,9 +49,18 @@ class Neo4JAdapter(DatabaseAdapter):
                 CALL (n) {
                     DETACH DELETE n
                 } IN TRANSACTIONS OF 10000 ROWS
-                """
+                """,
+                read_only=False,
             )
         )
+        result = run_maybe_nested(self.query("SHOW VECTOR INDEXES"))
+        for indexes in result:
+            index_name = indexes["name"]
+            query = "DROP INDEX $index"
+            params = {
+                "index": index_name,
+            }
+            run_maybe_nested(self.query(query, params))
 
     def create_vector_index(self):
         """Create vector indexes"""
@@ -81,9 +90,15 @@ class Neo4JAdapter(DatabaseAdapter):
                 self.query("CALL db.awaitIndexes(300)"),
             )
 
-    async def query(self, query: str, params: Dict[str, Any] = None, **kwargs):
+    async def query(
+        self, query: str, params: Dict[str, Any] = None, read_only=True, **kwargs
+    ):
         driver = neo4j.GraphDatabase.driver(self.uri, auth=(self.username, self.password))
         result_list = []
+        if read_only:
+            if not params:
+                params = {}
+            params["routing_"] = neo4j.RoutingControl.READ
         try:
             with driver.session(database=self.db_name) as session:
                 if params:
@@ -154,7 +169,7 @@ class Neo4JAdapter(DatabaseAdapter):
                 "objVector": obj_vector,
                 **relation_properties,
             }
-            await self.query(query, params=params)
+            await self.query(query, params=params, read_only=False)
         elif is_entity(data_model):
             node_label = self.sanitize_label(data_model.get("label"))
             vector = data_model.get("embedding")
@@ -194,7 +209,7 @@ class Neo4JAdapter(DatabaseAdapter):
                 "vector": vector,
                 **node_properties,
             }
-            await self.query(query, params=params)
+            await self.query(query, params=params, read_only=False)
         else:
             raise ValueError(
                 "The parameter `data_model` must be an `Entity` or `Relation` instance"
@@ -223,7 +238,7 @@ class Neo4JAdapter(DatabaseAdapter):
                 " $vector) YIELD node AS node, score",
                 "WITH node, score",
                 "WHERE score >= $threshold",
-                "RETURN {name: node.name, label: node.label} AS node, score",
+                "RETURN node AS node, score",
                 "LIMIT $numberOfNearestNeighbours",
             ]
         )
@@ -258,7 +273,6 @@ class Neo4JAdapter(DatabaseAdapter):
         params = {
             "numberOfNearestNeighbours": k,
             "threshold": threshold,
-            "k": k,
         }
         query_lines = []
 
@@ -367,6 +381,6 @@ class Neo4JAdapter(DatabaseAdapter):
                 "sqrt(subj_score * obj_score) AS score"
             )
         )
-        query_lines.append("LIMIT $k")
+        query_lines.append("LIMIT $numberOfNearestNeighbours")
         query = "\n".join(query_lines)
         return await self.query(query, params)
