@@ -85,7 +85,6 @@ class Optimizer(SynalinksSaveable):
 
         self.built = False
         self._program = None
-        self._optimizer = None
 
         self._initialize_tracker()
 
@@ -94,6 +93,7 @@ class Optimizer(SynalinksSaveable):
                 initializer=Empty(data_model=Iterations),
                 data_model=Iterations,
                 trainable=False,
+                name="iterations_"+self.name
             )
         self._iterations = iterations
 
@@ -150,23 +150,6 @@ class Optimizer(SynalinksSaveable):
         """
         return self._program
 
-    def set_meta_optimizer(self, meta_optimizer):
-        """Set the meta optimizer associated with this optimizer.
-
-        Args:
-            meta_optimizer (Optimizer): The meta optimizer
-        """
-        self._meta_optimizer = meta_optimizer
-
-    @property
-    def meta_optimizer(self):
-        """Get the optimizer associated with this optimizer.
-
-        Returns:
-            (Optimizer): The meta optimizeer
-        """
-        return self._meta_optimizer
-
     @property
     def reward_tracker(self):
         """Get the reward tracker from the associated program.
@@ -610,8 +593,9 @@ class Optimizer(SynalinksSaveable):
         if not reward:
             reward = 0.0
         for trainable_variable in trainable_variables:
+            current_predictions = trainable_variable.get("current_predictions")
             predictions = trainable_variable.get("predictions")
-            for p in predictions:
+            for p in current_predictions:
                 if p["reward"] is None:
                     p["reward"] = reward
                     nb_visit = trainable_variable.get("nb_visit")
@@ -622,6 +606,12 @@ class Optimizer(SynalinksSaveable):
                             "cumulative_reward": cumulative_reward + reward,
                         }
                     )
+            trainable_variable.update(
+                {
+                    "predictions": predictions + current_predictions,
+                    "current_predictions": [],
+                }
+            )
 
     async def assign_candidate(
         self,
