@@ -118,7 +118,7 @@ class Program(Trainer, Module):
             self.answer = synalinks.Generator(
                 data_model=AnswerWithThinking,
                 language_model=language_model,
-                name=self.name+"_generator",
+                name="generator_"+self.name,
             )
 
         async def call(self, inputs, training=False):
